@@ -5,6 +5,7 @@ import java.util.List;
 
 import org.gcube.portlets.user.gisviewer.client.commons.beans.DataResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GroupInfo;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerConfiguration;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItemsResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.SavedGroup;
@@ -31,5 +32,7 @@ public interface GisViewerService extends RemoteService {
 	
 	List<WfsTable> getDataResult(List<LayerItem> layerItems, String bbox);
 
+	LayerItemsResult getLayersInfoByLayerConfigurations(List<LayerConfiguration> layerConfigurations);
+
 	//public SavedGroup saveLayersGroup(GroupInfo groupInfo, String format);
 }
