@@ -21,6 +21,7 @@ import org.gcube.portlets.user.gisviewer.client.GisViewerService;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.BoundsMap;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.DataResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GroupInfo;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerConfiguration;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItemsResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.Property;
@@ -70,26 +71,8 @@ public abstract class GisViewerServiceImpl extends RemoteServiceServlet implemen
 			}
 		}
 
-		//		if (geoCaller!=null) return geoCaller;
-//		try {
-//
-//			GisViewerServiceParameters parameters = getParameters();
-//			String geoserverUrl = parameters.getGeoServerUrl();
-//			String geonetworkUrl = parameters.getGeoNetworkUrl();
-//			String gnUser = parameters.getGeoNetworkUser();
-//			String gnPwd = parameters.getGeoNetworkPwd();
-//			String gsUser = parameters.getGeoServerUser();
-//			String gsPwd = parameters.getGeoServerPwd();
-//
-//			geoCaller = new GeoCaller(geonetworkUrl, gnUser, gnPwd, geoserverUrl, gsUser, gsPwd, researchMethod);
-//
-//			return geoCaller;
-//		} catch (Exception e) {
-//			throw new Exception("Error initializing the GeoCaller", e);
-//		}
 	}
 
-	//http://geoserver-dev.d4science-ii.research-infrastructures.eu/geoserver/wfs?service=wfs&version=1.1.0&request=DescribeFeatureType&typeName=aquamaps:depthmean
 
 	public List<DataResult> getDataResult(List<String> urls) {
 		List<DataResult> result = new ArrayList<DataResult>();
@@ -135,134 +118,6 @@ public abstract class GisViewerServiceImpl extends RemoteServiceServlet implemen
 		}
 	}
 
-	// TO DELETE
-//	public GroupInfo getGroupsInfoOld(String groupName) {
-//		// search of geoserver that contains the group
-//		String gsUrl=null;
-//		try {
-//			GeoCaller geoCaller = getGeoCaller();
-//			gsUrl = geoCaller.getGeoServerForGroup(groupName);
-//			if (gsUrl==null)
-//				return null;
-//		} catch (Exception e) {
-//			e.printStackTrace();
-//			return null;
-//		}		
-//
-//		try {
-//			String gsGwcUrl = URLMakers.getGeoserverGwcUrl(gsUrl);
-//			String gsWmsUrl = URLMakers.getGeoserverWmsUrl(gsUrl);
-//
-//			//FIXME manage the exception
-//			GisViewerServiceParameters parameters = getParameters();
-//			String gsUser = parameters.getGeoServerUser();
-//			String gsPwd = parameters.getGeoServerPwd();
-//
-//			// connecting to the geoserver found
-//			GeoserverCaller geoserverCaller = new GeoserverCaller(gsUrl, gsUser, gsPwd);
-//
-//			GroupInfo result = new GroupInfo();
-//			ArrayList<LayerItem> layerItems = new ArrayList<LayerItem>();
-//
-//			GroupRest groupRest = geoserverCaller.getLayerGroup(groupName);
-//
-//			result.setName(groupName);
-//			result.setBounds(new BoundsMap(groupRest.getBounds().getMinx(), 
-//					groupRest.getBounds().getMiny(), 
-//					groupRest.getBounds().getMaxx(), 
-//					groupRest.getBounds().getMaxy(),
-//					groupRest.getBounds().getCrs()));
-//
-//			//			if (groupRest.getLayers().size() > 1) {
-//
-//			List<String> workspaces = new ArrayList<String>();
-//			List<String> layerNames = new ArrayList<String>();
-//			Boolean visible = true;
-//			for (String layerName: groupRest.getLayers()) {
-//				LayerRest layerRest = geoserverCaller.getLayer(layerName);
-//				// if the layer type is "border" and the border visualization is not activate, the layer is not processed
-//				if (!layerRest.getName().equals(Constants.borderLayer) || Constants.isBorderLayerVisible) {
-//					LayerItem layerItem = getLayerInfo(layerRest, groupRest, layerName, gsUrl, gsWmsUrl, gsGwcUrl);
-//					if (!layerItem.isBaseLayer()) {
-//						layerItem.setVisible(visible);
-//						visible = false;
-//					}
-//					layerItems.add(layerItem);
-//					workspaces.add(ServerGeoExtCostants.workSpace);
-//					layerNames.add(layerRest.getName());
-//				}
-//			}
-//
-//
-//			// set titles
-//			if (Constants.getLayerTitles) {
-//				List<String> titles = geoserverCaller.getLayerTitlesByWms(workspaces, layerNames);
-//				for (int i=0;i<titles.size();i++)
-//					if (titles.get(i)!=null)
-//						layerItems.get(i).setTitle(titles.get(i));
-//			}
-//
-//			result.setLayers(layerItems);
-//
-//			return result;
-//		} catch (Exception e) {
-//			System.out.println("gisViewer EXCEPTION: Error in getGroupInfo. Message=\""+e.getMessage()+"\"");
-//			System.out.println("geoserver_url="+gsUrl);
-//			System.out.println("Stacktrace: "+e.getStackTrace());
-//			e.printStackTrace();
-//			return null;
-//		}
-//	}
-
-//	private LayerItem getLayerInfo(LayerRest layerRest, GroupRest groupRest, String layerName, String gsUrl, String gsWmsUrl, String gsGwcUrl) {
-//		LayerItem layerItem = new LayerItem();
-//
-//		// set the dataStore
-//		layerItem.setDataStore(layerRest.getDatastore());
-//
-//		layerItem.setDefaultStyle(layerRest.getDefaultStyle());
-//		layerItem.setStyle(groupRest.getStyle(layerRest.getName()));
-//
-//		layerItem.setMaxExtent(groupRest.getBounds().getMinx(), 
-//				groupRest.getBounds().getMiny(), 
-//				groupRest.getBounds().getMaxx(),
-//				groupRest.getBounds().getMaxy(),
-//				groupRest.getBounds().getCrs());
-//
-//		layerItem.setBuffer(2);
-//		layerItem.setLayer(ServerGeoExtCostants.workSpace+":" + layerName);
-//		layerItem.setName(layerName);
-//		layerItem.setTitle(layerName);
-//
-//		if (layerRest.getType().contentEquals("RASTER")) {
-//			layerItem.setHasLegend(false);
-//			if (!layerRest.getName().equals(Constants.borderLayer)) {
-//				layerItem.setBaseLayer(BASE_LAYER);
-//				layerItem.setTrasparent(false);
-//			}
-//			else {
-//				layerItem.setBaseLayer(false);
-//				layerItem.setTrasparent(true);
-//			}
-//			layerItem.setClickData(false);
-//			layerItem.setVisible(true);
-//		} else {
-//			layerItem.setBaseLayer(false);
-//			layerItem.setClickData(true);
-//			layerItem.setStyles(layerRest.getStyles());
-//			layerItem.setHasLegend(true);
-//			layerItem.setTrasparent(true);
-//		}
-//
-//		layerItem.setUrl(gsGwcUrl);
-//		layerItem.setGeoserverUrl(gsUrl);
-//		layerItem.setGeoserverWmsUrl(gsWmsUrl);
-//
-//		// set layer properties info
-//		List<Property> properties = FeatureTypeParser.getProperties(gsUrl, layerItem.getLayer());
-//		layerItem.setProperties(properties);
-//		return layerItem;
-//	}
 
 	public LayerItemsResult getLayersInfo(List<String> layersName) {
 		LayerItemsResult layerItemsResult = new LayerItemsResult();
@@ -295,6 +150,7 @@ public abstract class GisViewerServiceImpl extends RemoteServiceServlet implemen
 					LayerItem layerItem = new LayerItem();
 					layerItem.setName(layerName);
 					layerItem.setTitle(layerCsw.getTitle());
+					layerItem.setLayer(layerCsw.getName());
 					layerItem.setVisible((countVisible++)<2);
 					layerItem.setUrl(gsGwcUrl);
 					layerItem.setGeoserverUrl(gsUrl);
@@ -309,7 +165,6 @@ public abstract class GisViewerServiceImpl extends RemoteServiceServlet implemen
 					layerItem.setStyle(layerRest.getDefaultStyle());
 
 					layerItem.setBuffer(2);
-					layerItem.setLayer(ServerGeoExtCostants.workSpace+":" + layerName);
 					if (layerRest.getType().contentEquals("RASTER")) {
 
 						CoverageTypeRest coverageTypeRest = geoserverCaller.getCoverageType(
@@ -380,80 +235,15 @@ public abstract class GisViewerServiceImpl extends RemoteServiceServlet implemen
 
 		int countVisible=0;
 		for (LayerItem layerItem: layerItems) {
-			String gsUrl = layerItem.getGeoserverUrl();
-			String layerName = layerItem.getName();
 			try {
-				if (gsUrl==null)
-					throw new Exception();
-				
-				GeoserverCaller geoserverCaller;
-				GisViewerServiceParameters parameters = getParameters();
-				String gsUser = parameters.getGeoServerUser();
-				String gsPwd = parameters.getGeoServerPwd();
-
-				geoserverCaller = new GeoserverCaller(gsUrl, gsUser, gsPwd);
-
-				String gsGwcUrl = URLMakers.getGeoserverGwcUrl(gsUrl);
-				String gsWmsUrl = URLMakers.getGeoserverWmsUrl(gsUrl);
-				layerItem.setUrl(gsGwcUrl);
-				layerItem.setGeoserverWmsUrl(gsWmsUrl);
-
+				putLayerInfoInLayerItem(layerItem);
 				layerItem.setVisible((countVisible++)<2);
-
-				LayerRest layerRest = geoserverCaller.getLayer(layerName);
-
-				// set the dataStore MIO
-				layerItem.setDataStore(layerRest.getDatastore());
-
-				layerItem.setDefaultStyle(layerRest.getDefaultStyle());
-				layerItem.setStyle(layerRest.getDefaultStyle());
-
-				layerItem.setBuffer(2);
-				layerItem.setLayer(ServerGeoExtCostants.workSpace+":" + layerName);
-				if (layerRest.getType().contentEquals("RASTER")) {
-					CoverageTypeRest coverageTypeRest = geoserverCaller.getCoverageType(
-							layerRest.getWorkspace(), 
-							layerRest.getCoveragestore(), 
-							layerName);
-
-					layerItem.setMaxExtent(coverageTypeRest.getLatLonBoundingBox().getMinx(), 
-							coverageTypeRest.getLatLonBoundingBox().getMiny(), 
-							coverageTypeRest.getLatLonBoundingBox().getMaxx(),
-							coverageTypeRest.getLatLonBoundingBox().getMaxy(),
-							coverageTypeRest.getLatLonBoundingBox().getCrs());
-					layerItem.setHasLegend(false);
-					layerItem.setBaseLayer(BASE_LAYER);
-					layerItem.setTrasparent(false);
-					layerItem.setClickData(false);
-				} else {
-					FeatureTypeRest featureTypeRest = geoserverCaller.getFeatureType(layerRest.getWorkspace(), 
-							layerRest.getDatastore(), 
-							layerName);
-
-					layerItem.setMaxExtent(featureTypeRest.getLatLonBoundingBox().getMinx(), 
-							featureTypeRest.getLatLonBoundingBox().getMiny(), 
-							featureTypeRest.getLatLonBoundingBox().getMaxx(),
-							featureTypeRest.getLatLonBoundingBox().getMaxy(),
-							featureTypeRest.getLatLonBoundingBox().getCrs());
-
-					layerItem.setBaseLayer(false);
-					layerItem.setClickData(true);
-					layerItem.setStyles(layerRest.getStyles());
-					layerItem.setHasLegend(true);
-
-					layerItem.setTrasparent(true);
-				}
 				layerItemsResult.addLayerItem(layerItem);
-				
-				// set layer properties info
-				List<Property> properties = FeatureTypeParser.getProperties(gsUrl, layerItem.getLayer());
-				layerItem.setProperties(properties);
-
 			} catch (Exception e) {
 				e.printStackTrace();
-				layerItemsResult.addStatusMessage("- Layer \""+layerName+"\" not found.");
+				layerItemsResult.addStatusMessage("- Layer \""+layerItem.getName()+"\" not found.");
 			}
-		} // for
+		}
 
 		// set eventually base layer
 		boolean isBaseLayer = false;
@@ -468,6 +258,273 @@ public abstract class GisViewerServiceImpl extends RemoteServiceServlet implemen
 	}
 
 
+	/**
+	 * @param layerItem
+	 */
+	private void putLayerInfoInLayerItem(LayerItem layerItem) throws Exception {
+		String gsUrl = layerItem.getGeoserverUrl();
+		String layerName = layerItem.getName();
+
+		if (gsUrl==null)
+			throw new Exception();
+		
+		GeoserverCaller geoserverCaller;
+		GisViewerServiceParameters parameters = getParameters();
+		String gsUser = parameters.getGeoServerUser();
+		String gsPwd = parameters.getGeoServerPwd();
+
+		geoserverCaller = new GeoserverCaller(gsUrl, gsUser, gsPwd);
+
+		String gsGwcUrl = URLMakers.getGeoserverGwcUrl(gsUrl);
+		String gsWmsUrl = URLMakers.getGeoserverWmsUrl(gsUrl);
+		layerItem.setUrl(gsGwcUrl);
+		layerItem.setGeoserverWmsUrl(gsWmsUrl);
+
+		LayerRest layerRest = geoserverCaller.getLayer(layerName);
+
+		// set the dataStore
+		layerItem.setDataStore(layerRest.getDatastore());
+
+		layerItem.setDefaultStyle(layerRest.getDefaultStyle());
+		layerItem.setStyle(layerRest.getDefaultStyle());
+
+		layerItem.setBuffer(2);
+//			layerItem.setLayer(ServerGeoExtCostants.workSpace+":" + layerName);
+		if (layerRest.getType().contentEquals("RASTER")) {
+			CoverageTypeRest coverageTypeRest = geoserverCaller.getCoverageType(
+					layerRest.getWorkspace(), 
+					layerRest.getCoveragestore(), 
+					layerName);
+
+			layerItem.setMaxExtent(coverageTypeRest.getLatLonBoundingBox().getMinx(), 
+					coverageTypeRest.getLatLonBoundingBox().getMiny(), 
+					coverageTypeRest.getLatLonBoundingBox().getMaxx(),
+					coverageTypeRest.getLatLonBoundingBox().getMaxy(),
+					coverageTypeRest.getLatLonBoundingBox().getCrs());
+			layerItem.setHasLegend(false);
+			layerItem.setBaseLayer(BASE_LAYER);
+			layerItem.setTrasparent(false);
+			layerItem.setClickData(false);
+		} else {
+			FeatureTypeRest featureTypeRest = geoserverCaller.getFeatureType(layerRest.getWorkspace(), 
+					layerRest.getDatastore(), 
+					layerName);
+
+			layerItem.setMaxExtent(featureTypeRest.getLatLonBoundingBox().getMinx(), 
+					featureTypeRest.getLatLonBoundingBox().getMiny(), 
+					featureTypeRest.getLatLonBoundingBox().getMaxx(),
+					featureTypeRest.getLatLonBoundingBox().getMaxy(),
+					featureTypeRest.getLatLonBoundingBox().getCrs());
+
+			layerItem.setBaseLayer(false);
+			layerItem.setClickData(true);
+			layerItem.setStyles(layerRest.getStyles());
+			layerItem.setHasLegend(true);
+
+			layerItem.setTrasparent(true);
+		}
+		
+		// set layer properties info
+		List<Property> properties = FeatureTypeParser.getProperties(gsUrl, layerItem.getLayer());
+		layerItem.setProperties(properties);
+	}
+
+//	String gsUrl = layerItem.getGeoserverUrl();
+//	String layerName = layerItem.getName();
+//	try {
+//		if (gsUrl==null)
+//			throw new Exception();
+//		
+//		GeoserverCaller geoserverCaller;
+//		GisViewerServiceParameters parameters = getParameters();
+//		String gsUser = parameters.getGeoServerUser();
+//		String gsPwd = parameters.getGeoServerPwd();
+//
+//		geoserverCaller = new GeoserverCaller(gsUrl, gsUser, gsPwd);
+//
+//		String gsGwcUrl = URLMakers.getGeoserverGwcUrl(gsUrl);
+//		String gsWmsUrl = URLMakers.getGeoserverWmsUrl(gsUrl);
+//		layerItem.setUrl(gsGwcUrl);
+//		layerItem.setGeoserverWmsUrl(gsWmsUrl);
+//
+//		layerItem.setVisible((countVisible++)<2);
+//
+//		LayerRest layerRest = geoserverCaller.getLayer(layerName);
+//
+//		// set the dataStore
+//		layerItem.setDataStore(layerRest.getDatastore());
+//
+//		layerItem.setDefaultStyle(layerRest.getDefaultStyle());
+//		layerItem.setStyle(layerRest.getDefaultStyle());
+//
+//		layerItem.setBuffer(2);
+////		layerItem.setLayer(ServerGeoExtCostants.workSpace+":" + layerName);
+//		if (layerRest.getType().contentEquals("RASTER")) {
+//			CoverageTypeRest coverageTypeRest = geoserverCaller.getCoverageType(
+//					layerRest.getWorkspace(), 
+//					layerRest.getCoveragestore(), 
+//					layerName);
+//
+//			layerItem.setMaxExtent(coverageTypeRest.getLatLonBoundingBox().getMinx(), 
+//					coverageTypeRest.getLatLonBoundingBox().getMiny(), 
+//					coverageTypeRest.getLatLonBoundingBox().getMaxx(),
+//					coverageTypeRest.getLatLonBoundingBox().getMaxy(),
+//					coverageTypeRest.getLatLonBoundingBox().getCrs());
+//			layerItem.setHasLegend(false);
+//			layerItem.setBaseLayer(BASE_LAYER);
+//			layerItem.setTrasparent(false);
+//			layerItem.setClickData(false);
+//		} else {
+//			FeatureTypeRest featureTypeRest = geoserverCaller.getFeatureType(layerRest.getWorkspace(), 
+//					layerRest.getDatastore(), 
+//					layerName);
+//
+//			layerItem.setMaxExtent(featureTypeRest.getLatLonBoundingBox().getMinx(), 
+//					featureTypeRest.getLatLonBoundingBox().getMiny(), 
+//					featureTypeRest.getLatLonBoundingBox().getMaxx(),
+//					featureTypeRest.getLatLonBoundingBox().getMaxy(),
+//					featureTypeRest.getLatLonBoundingBox().getCrs());
+//
+//			layerItem.setBaseLayer(false);
+//			layerItem.setClickData(true);
+//			layerItem.setStyles(layerRest.getStyles());
+//			layerItem.setHasLegend(true);
+//
+//			layerItem.setTrasparent(true);
+//		}
+//		layerItemsResult.addLayerItem(layerItem);
+//		
+//		// set layer properties info
+//		List<Property> properties = FeatureTypeParser.getProperties(gsUrl, layerItem.getLayer());
+//		layerItem.setProperties(properties);
+//
+//	} catch (Exception e) {
+//		e.printStackTrace();
+//		layerItemsResult.addStatusMessage("- Layer \""+layerName+"\" not found.");
+//	}
+
+	@Override
+	public LayerItemsResult getLayersInfoByLayerConfigurations(List<LayerConfiguration> layerConfigurations) {
+		System.out.println("OKOK");
+		LayerItemsResult layerItemsResult = new LayerItemsResult();
+		Map<String, GeoserverCaller> geoserverCallers = new HashMap<String, GeoserverCaller>(); 
+		
+		for (LayerConfiguration layerConfiguration : layerConfigurations) {
+			if (layerConfiguration.getLayerItem()!=null) {
+				LayerItem layerItem = layerConfiguration.getLayerItem();
+				try {
+					putLayerInfoInLayerItem(layerItem);
+					layerItem.setVisible(layerConfiguration.isVisible());
+					layerItemsResult.addLayerItem(layerItem);
+				} catch (Exception e) {
+					e.printStackTrace();
+					layerItemsResult.addStatusMessage("- Layer \""+layerItem.getName()+"\" not found.");
+				}
+			}
+			
+			else if (layerConfiguration.getLayerName()!=null) {
+				String layerName = layerConfiguration.getLayerName();
+				
+				try {
+					LayerItem layerItem = getLayerInfoByLayerName(layerName, geoserverCallers);
+					layerItem.setVisible(layerConfiguration.isVisible());
+					layerItemsResult.addLayerItem(layerItem);
+				} catch (Exception e) {
+					e.printStackTrace();
+					layerItemsResult.addStatusMessage("- Layer \""+layerName+"\" not found.");
+				}
+			}
+		}
+		return layerItemsResult;
+	}
+
+	
+	/**
+	 * @param layerName
+	 * @param geoserverCallers 
+	 * @return
+	 */
+	private LayerItem getLayerInfoByLayerName(String layerName, Map<String, GeoserverCaller> geoserverCallers) throws Exception {
+		GeoCaller geoCaller = getGeoCaller();
+
+		CswLayersResult cswLayerResult = geoCaller.getLayersFromCsw(null, 1, 1, false, true, FILTER_TYPE.ANY_TEXT, layerName);				
+		if (cswLayerResult.getLayers().size()==0)
+			throw new Exception("CswLayerResult is empty.");
+		else {
+			LayerCsw layerCsw = cswLayerResult.getLayers().get(0);
+			String gsUrl = URLMakers.getGeoserverUrlFromWmsUrl(layerCsw.getGeoserverUrl());
+			String gsGwcUrl = URLMakers.getGeoserverGwcUrl(gsUrl);
+			String gsWmsUrl = URLMakers.getGeoserverWmsUrl(gsUrl);
+
+			GeoserverCaller geoserverCaller;
+			if ((geoserverCaller = geoserverCallers.get(gsUrl))==null) {
+				GisViewerServiceParameters parameters = getParameters();
+				String gsUser = parameters.getGeoServerUser();
+				String gsPwd = parameters.getGeoServerPwd();
+				geoserverCaller = new GeoserverCaller(gsUrl, gsUser, gsPwd);
+				geoserverCallers.put(gsUrl, geoserverCaller);
+			}
+
+			LayerItem layerItem = new LayerItem();
+			layerItem.setName(layerName);
+			layerItem.setTitle(layerCsw.getTitle());
+			layerItem.setLayer(layerCsw.getName());
+			layerItem.setUrl(gsGwcUrl);
+			layerItem.setGeoserverUrl(gsUrl);
+			layerItem.setGeoserverWmsUrl(gsWmsUrl);
+
+			LayerRest layerRest = geoserverCaller.getLayer(layerName);
+
+			// set the dataStore
+			layerItem.setDataStore(layerRest.getDatastore());
+
+			layerItem.setDefaultStyle(layerRest.getDefaultStyle());
+			layerItem.setStyle(layerRest.getDefaultStyle());
+
+			layerItem.setBuffer(2);
+			if (layerRest.getType().contentEquals("RASTER")) {
+
+				CoverageTypeRest coverageTypeRest = geoserverCaller.getCoverageType(
+						layerRest.getWorkspace(), 
+						layerRest.getCoveragestore(), 
+						layerName);
+
+				layerItem.setMaxExtent(coverageTypeRest.getLatLonBoundingBox().getMinx(), 
+						coverageTypeRest.getLatLonBoundingBox().getMiny(), 
+						coverageTypeRest.getLatLonBoundingBox().getMaxx(),
+						coverageTypeRest.getLatLonBoundingBox().getMaxy(),
+						coverageTypeRest.getLatLonBoundingBox().getCrs());
+				layerItem.setHasLegend(false);
+				layerItem.setBaseLayer(BASE_LAYER);
+				layerItem.setTrasparent(false);
+				layerItem.setClickData(false);
+			} else {
+				FeatureTypeRest featureTypeRest = geoserverCaller.getFeatureType(layerRest.getWorkspace(), 
+						layerRest.getDatastore(), 
+						layerName);
+
+				layerItem.setMaxExtent(featureTypeRest.getLatLonBoundingBox().getMinx(), 
+						featureTypeRest.getLatLonBoundingBox().getMiny(), 
+						featureTypeRest.getLatLonBoundingBox().getMaxx(),
+						featureTypeRest.getLatLonBoundingBox().getMaxy(),
+						featureTypeRest.getLatLonBoundingBox().getCrs());
+
+				layerItem.setBaseLayer(false);
+				layerItem.setClickData(true);
+				layerItem.setStyles(layerRest.getStyles());
+				layerItem.setHasLegend(true);
+
+				layerItem.setTrasparent(true);
+			}
+
+			// set layer properties info
+			List<Property> properties = FeatureTypeParser.getProperties(gsUrl, layerItem.getLayer());
+			layerItem.setProperties(properties);
+
+			return layerItem;
+		}
+	}
+
 	/**
 	 * {@inheritDoc}
 	 */
